@@ -1,11 +1,11 @@
 package VM::JiffyBox;
-{
-  $VM::JiffyBox::VERSION = '0.0232'; # TRIAL
-}
-
+$VM::JiffyBox::VERSION = '0.027'; # TRIAL
 # The line below is recognised by Dist::Zilla and taken for CPAN packaging
 # ABSTRACT: OO-API for JiffyBox Virtual Machine
 
+use strict;
+use warnings;
+
 use Moo;
 use JSON;
 use LWP::UserAgent;
@@ -43,7 +43,7 @@ sub get_details {
     # POSSIBLE EXIT
     unless ($response->is_success) {
         $self->last ($response->status_line);
-        return 0;
+        return;
     }
 
     my $details = from_json($response->decoded_content);
@@ -61,14 +61,14 @@ sub get_id_from_name {
     my $details = $self->get_details;
 
     # EXIT if no details
-    return 0 unless $details;
+    return unless $details;
 
     $self->last         ( $details );
 
     # EXIT if no expected result
-    return 0 unless (reftype $details eq 'HASH');
-    return 0 unless (exists $details->{result});
-    return 0 unless (reftype $details->{result} eq 'HASH');
+    return unless (reftype $details eq 'HASH');
+    return unless (exists $details->{result});
+    return unless (reftype $details->{result} eq 'HASH');
 
     $self->details_cache( $details );
     
@@ -76,13 +76,13 @@ sub get_id_from_name {
     foreach my $box (values %{$details->{result}}) {
 
         # EXIT if no expected result
-        return 0 unless (reftype $box eq 'HASH');
+        return unless (reftype $box eq 'HASH');
 
         return $box->{id} if ($box->{name} eq $box_name);
     }
 
     # if we reach here, this means there was no match
-    return 0;
+    return;
 }
 
 sub get_vm {
@@ -112,7 +112,7 @@ sub create_vm {
     # POSSIBLE EXIT
     unless ($response->is_success) {
         $self->last ($response->status_line);
-        return 0;
+        return;
     }
 
     $self->last(from_json($response->decoded_content));
@@ -121,7 +121,7 @@ sub create_vm {
     # TODO: should check the array for more messages
     if (exists $self->last->{messages}->[0]->{type}
         and    $self->last->{messages}->[0]->{type} eq 'error') {
-        return 0;
+        return;
     }
 
     my $box_id = $self->last->{result}->{id};
@@ -130,19 +130,69 @@ sub create_vm {
     return $box;
 }
 
+sub get_distributions {
+    my ($self) = shift;
+
+    my $url      = $self->base_url . '/distributions';
+    my $response = $self->ua->get( $url );
+
+    unless ( $response->is_success ) {
+        $self->last ($response->status_line);
+        return;
+    }
+
+    $self->last( from_json( $response->decoded_content ) );
+
+    return $self->last;
+}
+
+sub get_plans {
+    my ($self) = shift;
+
+    my $url      = $self->base_url . '/plans';
+    my $response = $self->ua->get( $url );
+
+    unless ( $response->is_success ) {
+        $self->last ($response->status_line);
+        return;
+    }
+
+    $self->last( from_json( $response->decoded_content ) );
+
+    return $self->last;
+}
+
+sub get_plan_details {
+    my ($self, $id_or_name) = @_;
+
+    my $url      = $self->base_url . '/plans/' . $id_or_name;
+    my $response = $self->ua->get( $url );
+
+    unless ( $response->is_success ) {
+        $self->last ($response->status_line);
+        return;
+    }
+
+    $self->last( from_json( $response->decoded_content ) );
+
+    return $self->last;
+}
+
 1;
 
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 VM::JiffyBox - OO-API for JiffyBox Virtual Machine
 
 =head1 VERSION
 
-version 0.0232
+version 0.027
 
 =head1 SYNOPSIS
 
@@ -196,8 +246,6 @@ version 0.0232
 
 (See the C<examples> directory for more examples of working code.)
 
-=encoding utf8
-
 =head1 ERROR HANDLING
 
 All methods will return C<0> on failure, so you can check for this with a simple C<if> on the return value.
@@ -285,7 +333,22 @@ Optinal.
 There may be more options.
 Please see the official documentation of I<JiffyBox>.
 
-B<Note:> This methods interface changed (as announced) and is not compatible with older releases of L<VM::JiffyBox>.
+=head2 get_distributions
+
+Get information about available distribution images for the virtual machines.
+Returns a hashref.
+
+=head2 get_plans
+
+Get information about existing plans (pricing).
+Takes no arguments.
+Returns a hashref.
+
+=head2 get_plan_details
+
+Returns details for a plan-id or name (pricing model).
+Pass name or ID as an argument to the method.
+Returns a hashref.
 
 =head1 METHODS (SHORTCUTS)
 
@@ -301,6 +364,8 @@ Returns C<0> if there was no match.
 
 =head1 SEE ALSO
 
+This is a software library for the I<perl programming language>.
+
 =over
 
 =item *
