@@ -1,10 +1,10 @@
 package VM::JiffyBox::Box;
-{
-  $VM::JiffyBox::Box::VERSION = '0.0232'; # TRIAL
-}
-
+$VM::JiffyBox::Box::VERSION = '0.027'; # TRIAL
 # ABSTRACT: Representation of a Virtual Machine in JiffyBox
 
+use strict;
+use warnings;
+
 use Moo;
 use JSON;
 
@@ -32,7 +32,7 @@ sub get_backups {
     unless ($response->is_success) {
 
         $self->last ( $response->status_line );
-        return 0;
+        return;
     }
 
     my $backup_info = from_json($response->decoded_content);
@@ -60,7 +60,7 @@ sub get_details {
     unless ($response->is_success) {
 
         $self->last ( $response->status_line );
-        return 0;
+        return;
     }
 
     my $details = from_json($response->decoded_content);
@@ -87,7 +87,7 @@ sub start {
     unless ($response->is_success) {
 
         $self->last ( $response->status_line );
-        return 0;
+        return;
     }
 
     my $start_info = from_json($response->decoded_content);
@@ -113,7 +113,7 @@ sub stop {
     unless ($response->is_success) {
 
         $self->last ( $response->status_line );
-        return 0;
+        return;
     }
 
     my $stop_info = from_json($response->decoded_content);
@@ -137,7 +137,7 @@ sub delete {
     unless ($response->is_success) {
 
         $self->last ( $response->status_line );
-        return 0;
+        return;
     }
 
     my $delete_info = from_json($response->decoded_content);
@@ -153,13 +153,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 VM::JiffyBox::Box - Representation of a Virtual Machine in JiffyBox
 
 =head1 VERSION
 
-version 0.0232
+version 0.027
 
 =head1 SYNOPSIS
 
@@ -191,8 +193,6 @@ You then can do a lot of stuff with this box:
 
 (See also the SYNOPSIS of L<VM::JiffyBox> or the C<examples> directory for more examples of working code.)
 
-=encoding utf8
-
 =head1 ERROR HANDLING
 
 All methods will return C<0> on failure, so you can check for this with a simple C<if> on the return value.
